plugin

package
v2.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 23, 2026 License: Apache-2.0 Imports: 14 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func JWT

func JWT() *_JwtLoginPlugin

New create a new LoginAsJwt plugin, secret is the secret key for jwt, idKey is the key for id in jwt

func LoginInHead

func LoginInHead() *_loginInHead

New create a new LoginAsHeader plugin

func SetConfigSuffix

func SetConfigSuffix(suffix string) *_SetConfigSuffixPlugin

func Silent

func Silent(url ...string) *_SilenceSetter

Types

type DelimSetter

type DelimSetter struct {
	// contains filtered or unexported fields
}

func NewDelimSetter

func NewDelimSetter(strs ...string) *DelimSetter

func (*DelimSetter) SetDelim

func (d *DelimSetter) SetDelim() [2]string

type Html5Router

type Html5Router struct {
	goblet.Route  `/`
	goblet.Render `html=/`
	goblet.GroupController
	// contains filtered or unexported fields
}

func Html5RoutePages

func Html5RoutePages(include []string, excluded ...[]string) *Html5Router

func (*Html5Router) Get

func (p *Html5Router) Get(ctx *goblet.Context) error

type HtmlRenderPlugin

type HtmlRenderPlugin struct {
	// contains filtered or unexported fields
}

func (*HtmlRenderPlugin) AddCfgAndInit

func (h *HtmlRenderPlugin) AddCfgAndInit(s *goblet.Server) error

实现NewPlugin接口

func (*HtmlRenderPlugin) Init

func (*HtmlRenderPlugin) PrepareInstance

func (*HtmlRenderPlugin) Type

func (h *HtmlRenderPlugin) Type() string

type PageRedirector

type PageRedirector struct {
	goblet.Route  `/`
	goblet.Render `html`
	goblet.GroupController
	// contains filtered or unexported fields
}

func PageRedirect

func PageRedirect(matcher *regexp.Regexp, target string, withOriginalAsQuery bool) *PageRedirector

PageRedirect Create a page redirector match the matcher and redirect to target, if withOriginalAsQuery is true, the original url will be append to the target url's query part as target?original=original

func (*PageRedirector) Get

func (p *PageRedirector) Get(ctx *goblet.Context) error

type XmlRenderPlugin

type XmlRenderPlugin struct {
}

func (*XmlRenderPlugin) AddCfgAndInit

func (x *XmlRenderPlugin) AddCfgAndInit(s *goblet.Server) error

实现NewPlugin接口

func (*XmlRenderPlugin) Init

func (*XmlRenderPlugin) PrepareInstance

func (*XmlRenderPlugin) Type

func (x *XmlRenderPlugin) Type() string

Directories

Path Synopsis

Jump to