Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func JWT ¶
func JWT() *_JwtLoginPlugin
New create a new LoginAsJwt plugin, secret is the secret key for jwt, idKey is the key for id in jwt
func SetConfigSuffix ¶
func SetConfigSuffix(suffix string) *_SetConfigSuffixPlugin
Types ¶
type DelimSetter ¶
type DelimSetter struct {
// contains filtered or unexported fields
}
func NewDelimSetter ¶
func NewDelimSetter(strs ...string) *DelimSetter
func (*DelimSetter) SetDelim ¶
func (d *DelimSetter) SetDelim() [2]string
type Html5Router ¶
type Html5Router struct {
goblet.Route `/`
goblet.Render `html=/`
goblet.GroupController
// contains filtered or unexported fields
}
func Html5RoutePages ¶
func Html5RoutePages(include []string, excluded ...[]string) *Html5Router
type HtmlRenderPlugin ¶
type HtmlRenderPlugin struct {
// contains filtered or unexported fields
}
func (*HtmlRenderPlugin) AddCfgAndInit ¶
func (h *HtmlRenderPlugin) AddCfgAndInit(s *goblet.Server) error
实现NewPlugin接口
func (*HtmlRenderPlugin) Init ¶
func (h *HtmlRenderPlugin) Init(s render.RenderServer, funcs template.FuncMap)
func (*HtmlRenderPlugin) PrepareInstance ¶
func (h *HtmlRenderPlugin) PrepareInstance(c render.RenderContext) (render.RenderInstance, error)
func (*HtmlRenderPlugin) Type ¶
func (h *HtmlRenderPlugin) Type() string
type PageRedirector ¶
type PageRedirector struct {
goblet.Route `/`
goblet.Render `html`
goblet.GroupController
// contains filtered or unexported fields
}
func PageRedirect ¶
func PageRedirect(matcher *regexp.Regexp, target string, withOriginalAsQuery bool) *PageRedirector
PageRedirect Create a page redirector match the matcher and redirect to target, if withOriginalAsQuery is true, the original url will be append to the target url's query part as target?original=original
type XmlRenderPlugin ¶
type XmlRenderPlugin struct {
}
func (*XmlRenderPlugin) AddCfgAndInit ¶
func (x *XmlRenderPlugin) AddCfgAndInit(s *goblet.Server) error
实现NewPlugin接口
func (*XmlRenderPlugin) Init ¶
func (x *XmlRenderPlugin) Init(s render.RenderServer, funcs template.FuncMap)
func (*XmlRenderPlugin) PrepareInstance ¶
func (x *XmlRenderPlugin) PrepareInstance(c render.RenderContext) (render.RenderInstance, error)
func (*XmlRenderPlugin) Type ¶
func (x *XmlRenderPlugin) Type() string
Source Files
¶
Click to show internal directories.
Click to hide internal directories.